﻿Try {
	Write-Output "[INFOR]Importing module $($env:SMS_ADMIN_UI_PATH.Substring(0,$env:SMS_ADMIN_UI_PATH.Length – 5) + '\ConfigurationManager.psd1') ";
    Import-Module ($env:SMS_ADMIN_UI_PATH.Substring(0,$env:SMS_ADMIN_UI_PATH.Length – 5) + '\ConfigurationManager.psd1') -ErrorAction Stop;
    Write-Output "[INFOR]Success";
}
Catch {
    Write-Output "[ERROR]HResult=$($_.Exception.HResult): $($_.Exception.Message)";
    Write-Output 1002;
    Exit 1002;
}
Try {
	$SiteCode = Get-PSDrive | where {$_.Provider -like "*CMSite*"} | Select-Object -ExpandProperty Name;
    Write-Output "[INFOR]Setting location '$($SiteCode):'";
	Set-Location "$($SiteCode):" -ErrorAction Stop -ErrorVariable ErrSetLocation;
    Write-Output "[INFOR]Success";
}
Catch {
    Write-Output "[ERROR]HResult=$($_.Exception.HResult): $($_.Exception.Message)";
    Write-Output 1003;
    Exit 1003;
    }
Try {
	Write-Output "[INFOR]Reading deployment configuration '$($Path)'";
    [xml]$Applications = [System.IO.File]::ReadLines($Path);
    Write-Output "[INFOR]Success";
}
Catch {
	Write-Output "[ERROR]HResult=$($_.Exception.HResult): $($_.Exception.Message)";
    Write-Output 1004;
    Exit 1004;
}

foreach ($App in $Applications.Applications.Application) {
	Try {
		Write-Output "[INFOR]Creating SCCM Apclication '$($App.Name)'";
        if ($App.AutoInstall) {
			$NewApp = New-CMApplication -Name "$($App.Name)" -Manufacturer "$($App.Manufacturer)" -Description "$($App.Description)" `
					  -SoftwareVersion "$($App.SoftwareVersion)" -AutoInstall $true -ErrorAction Stop;
        }
        else {
			$NewApp = New-CMApplication -Name "$($App.Name)" -Manufacturer "$($App.Manufacturer)" -Description "$($App.Description)" `
                      -SoftwareVersion "$($App.SoftwareVersion)" -ErrorAction Stop;
		}
        Write-Output "[INFOR]Success";
   	}
    Catch {
		Write-Output "[ERROR]HResult=$($_.Exception.HResult): $($_.Exception.Message)";
        Write-Output 1010;
        Exit 1010;
    }
    foreach ($DeploymentType in $App.DeploymentTypes) {
		Try {
			if ($DeploymentType.DeploymentType.MsiInstaller) {
				Write-Output "[INFOR]Adding deployment type 'MSI' for SCCM Apclication '$($NewApp.LocalizedDisplayName)'";
		if ((Get-Command Add-CMDeploymentType).Parameters.ContainsKey('AutoIdentifyFromInstallationFile')) {
                Add-CMDeploymentType -ApplicationName "$($NewApp.LocalizedDisplayName)" -MsiInstaller -AutoIdentifyFromInstallationFile `
                                     -ForceForUnknownPublisher $true -InstallationFileLocation "$($DeploymentType.DeploymentType.InstallationFileLocation)" `
                                     -InstallationProgram "$($DeploymentType.DeploymentType.InstallationProgram)" `
                                     -InstallationBehaviorType "$($DeploymentType.DeploymentType.InstallationBehaviorType)" -ErrorAction Stop;
		}
		else {
		Add-CMDeploymentType -ApplicationName "$($NewApp.LocalizedDisplayName)" -MsiInstaller -AutoIdentifyFromIntallationFile `
                                     -ForceForUnknownPublisher $true -InstallationFileLocation "$($DeploymentType.DeploymentType.InstallationFileLocation)" `
                                     -InstallationProgram "$($DeploymentType.DeploymentType.InstallationProgram)" `
                                     -InstallationBehaviorType "$($DeploymentType.DeploymentType.InstallationBehaviorType)" -ErrorAction Stop;
		}
                $GetMSITypeStatus = Get-CMDeploymentType -ApplicationName "$($NewApp.LocalizedDisplayName)" | Where-Object {$_.Technology -eq "MSI"};
                Set-CMDeploymentType -ApplicationName "$($NewApp.LocalizedDisplayName)" -DeploymentTypeName "$($GetMSITypeStatus.LocalizedDisplayName)" `
                                     -MsiOrScriptInstaller -RebootBehavior "$($DeploymentType.DeploymentType.RebootBehavior)" `
                                     -LogonRequirementType "$($DeploymentType.DeploymentType.LogonRequirementType)" `
                                     -MaximumAllowedRunTimeMinutes "$($DeploymentType.DeploymentType.MaximumAllowedRunTimeMinutes)" `
                                     -UninstallProgram "$($DeploymentType.DeploymentType.UninstallProgram)" -ErrorAction Stop;
                Write-Output "[INFOR]Success";
            }
            elseif ($DeploymentType.DeploymentType.AppVInstaller) {
				Write-Output "[INFOR]Adding deployment type 'AppV' for SCCM Apclication '$($NewApp.LocalizedDisplayName)'";
                Add-CMDeploymentType -ApplicationName "$($NewApp.LocalizedDisplayName)" -AppvInstaller -AutoIdentifyFromInstallationFile `
                                     -ForceForUnknownPublisher $true -InstallationFileLocation "$($DeploymentType.DeploymentType.InstallationFileLocation)" `
                                     -ErrorAction Stop;
                Write-Output "[INFOR]Success";
            }    
            elseif ($DeploymentType.DeploymentType.AppV5xInstaller) {
				Write-Output "[INFOR]Adding deployment type 'AppV5x' for SCCM Apclication '$($NewApp.LocalizedDisplayName)'";
                Add-CMDeploymentType -ApplicationName "$($NewApp.LocalizedDisplayName)" -AppV5xInstaller -AutoIdentifyFromInstallationFile `
                                     -ForceForUnknownPublisher $true -InstallationFileLocation "$($DeploymentType.DeploymentType.InstallationFileLocation)" `
                                     -ErrorAction Stop;
                Write-Output "[INFOR]Success";
            }
        }
        Catch {
			Remove-CMApplication -Name "$($NewApp.LocalizedDisplayName)" -ErrorAction SilentlyContinue -Force;
            Write-Output "[INFOR]Removing SCCM Apclication '$($NewApp.LocalizedDisplayName)'";
            Write-Output "[ERROR]HResult=$($_.Exception.HResult): $($_.Exception.Message)";
            Write-Output 1020;
            Exit 1020;
        }
    }
}
Write-Output "[INFOR]The Application and Deployment type has been added successfully";
Write-Output 0;
Exit 0;
